@@ -13,9 +13,9 @@ def build(path, tag, *args):
 
 def pull(tag):
     fmt.echo_info("Pulling image {}".format(tag))
-    utils.execute("docker", "pull", tag)
+    utils.docker("pull", tag)
 
 
 def push(tag):
     fmt.echo_info("Pushing image {}".format(tag))
-    utils.execute("docker", "push", tag)
+    utils.docker("push", tag)
